@@ -1,9 +1,8 @@
-# @(#)Ident: ErrorLeader.pm 2013-11-20 15:05 pjf ;
+# @(#)Ident: ErrorLeader.pm 2014-01-24 20:17 pjf ;
 
 package Unexpected::TraitFor::ErrorLeader;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.20.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use List::Util        qw( first );
 use Unexpected::Types qw( NonZeroPositiveInt SimpleStr );
@@ -82,11 +81,6 @@ Unexpected::TraitFor::ErrorLeader - Prepends a leader to the exception
    extends 'Unexpected';
    with    'Unexpected::TraitFor::ErrorLeader';
 
-=head1 Version
-
-This documents version v0.20.$Rev: 1 $
-of L<Unexpected::TraitFor::ErrorLeader>
-
 =head1 Description
 
 Prepends a one line stack summary to the exception error message
